@@ -14,7 +14,7 @@ def datetime_to_utc_datetime_iso8601(datetime, day_granularity=False):
     """
     # ignore microseconds
     datetime = datetime.replace(microsecond=0)
-    result = datetime.isoformat() + 'Z'
+    result = datetime.isoformat() + "Z"
     if day_granularity:
         result = result[:-10]
     return result
@@ -31,4 +31,3 @@ def utc_datetime_iso8601_to_datetime(utc_datetime):
 
     """
     return iso8601.parse_date(utc_datetime).replace(tzinfo=None)
-
